@@ -1,7 +1,5 @@
-package HTTP::Request::FromFetch;
-use strict;
-use warnings;
-use Filter::signatures;
+package HTTP::Request::FromFetch 0.53;
+use 5.020;
 use feature 'signatures';
 no warnings 'experimental::signatures';
 use Carp 'croak';
@@ -9,8 +7,6 @@ use JSON;
 use PerlX::Maybe;
 use HTTP::Request::CurlParameters;
 
-our $VERSION = '0.52';
-
 =head1 NAME
 
 HTTP::Request::FromFetch - turn a Javascript fetch() statement into HTTP::Request
