@@ -1,6 +1,5 @@
-package HTTP::Request::FromWget;
-use strict;
-use warnings;
+package HTTP::Request::FromWget 0.53;
+use 5.020;
 use HTTP::Request;
 use HTTP::Request::Common;
 use URI;
@@ -11,12 +10,9 @@ use HTTP::Request::Generator 'generate_requests';
 use PerlX::Maybe;
 use MIME::Base64 'encode_base64';
 
-use Filter::signatures;
 use feature 'signatures';
 no warnings 'experimental::signatures';
 
-our $VERSION = '0.52';
-
 =head1 NAME
 
 HTTP::Request::FromWget - create a HTTP::Request from a wget command line
